==> apache-camel-3.4.2-src.zip: apache-camel-3.4.2/core/camel-core/src/test/java/org/apache/camel/processor/DoTryCatchWithSplitterTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.processor;

import org.apache.camel.ContextTestSupport;
import org.apache.camel.builder.RouteBuilder;
import org.junit.jupiter.api.Test;

/**
 *
 */
public class DoTryCatchWithSplitterTest extends ContextTestSupport {

    @Test
    public void testTryCatchWithSplitter() throws Exception {
        getMockEndpoint("mock:line").expectedBodiesReceived("Tiger", "Camel");
        getMockEndpoint("mock:iae").expectedBodiesReceived("Tiger,Camel,Donkey");

        template.sendBody("direct:start", "Tiger,Camel,Donkey");

        assertMockEndpointsSatisfied();
    }

    @Override
    protected RouteBuilder createRouteBuilder() throws Exception {
        return new RouteBuilder() {
            @Override
            public void configure() throws Exception {
                from("direct:start").doTry().split(body().tokenize(",")).to("direct:line").endDoTry().doCatch(IllegalArgumentException.class).to("mock:iae").end();

                from("direct:line").choice().when(body().contains("Donkey")).throwException(new IllegalArgumentException("Donkey not allowed")).otherwise().to("mock:line");
            }
        };
    }
}

==> apache-camel-4.0.0-src.zip: apache-camel-4.0.0/core/camel-core/src/test/java/org/apache/camel/processor/DoTryCatchWithSplitterTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.processor;

import org.apache.camel.ContextTestSupport;
import org.apache.camel.builder.RouteBuilder;
import org.junit.jupiter.api.Test;

/**
 *
 */
public class DoTryCatchWithSplitterTest extends ContextTestSupport {

    @Test
    public void testTryCatchWithSplitter() throws Exception {
        getMockEndpoint("mock:line").expectedBodiesReceived("Tiger", "Camel");
        getMockEndpoint("mock:iae").expectedBodiesReceived("Tiger,Camel,Donkey");

        template.sendBody("direct:start", "Tiger,Camel,Donkey");

        assertMockEndpointsSatisfied();
    }

    @Override
    protected RouteBuilder createRouteBuilder() throws Exception {
        return new RouteBuilder() {
            @Override
            public void configure() throws Exception {
                from("direct:start").doTry().split(body().tokenize(",")).to("direct:line").endDoTry()
                        .doCatch(IllegalArgumentException.class).to("mock:iae").end();

                from("direct:line").choice().when(body().contains("Donkey"))
                        .throwException(new IllegalArgumentException("Donkey not allowed")).otherwise().to("mock:line");
            }
        };
    }
}
